#    $Id: Config.pm,v 1.8 2004/07/25 22:43:52 kevinspicer Exp $
#    MailScanner-MRTG 
#    Copyright (C) 2002-3 Dale Lovelace <dlovelace@hotels.com>
#    With various bits shamelessly stolen from others
#    Restructuring and Substantial Modifications 
#    Copyright (C) 2003-4 Kevin Spicer <kevin@kevinspicer.co.uk>
#    with contributions from many other (see CHANGELOG for details)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Please submit all bug reports, patches etc via the sourceforge project 
#   page at http://sourceforge.net/projects/mailscannermrtg
#
#
package MSMRTG::Config;
require Exporter;

@ISA=qw(Exporter);
@EXPORT=qw($configfile $version %timedate %Config ItoE ReadConfFile GetTimeDate);

use FileHandle;
$configfile="";
$version="0";
@timedate=();
%Config=();

#
# Read the configuration file. Borrowed from MailScanner :-) 
# These 3 subs are copyright Julian Field. Released under the GPL.
#
sub ItoE {
  my($val) = @_;
  lc($ItoE{$val}) or lc($val);
}
sub EtoI {
  my($val) = @_;
  lc($EtoI{$val}) or lc($val);
}
sub ReadConfFile {
  if ($MSMRTG::Debug::debug) { 
    MSMRTG::Debug::Debug("Beginning sub ReadConfFile") ;
    MSMRTG::Debug::Debug("Configfile", $configfile);
  }

  # Slurp the whole file into a big hash.
  # Don't Complain if we see the same keyword more than once.
  my($fileh, $linecounter, $key, $value);

  $fileh = new FileHandle;
  $fileh->open($configfile) or
    MSMRTG::Log::Log_Syslog("err",1,"Could not read configuration file " . $configfile . " " .  $!);
  $linecounter = 0;
  while(<$fileh>) {
    $linecounter++;
    chomp;
    s/#.*$//;
    s/^\s+//;
    s/\s+$//;
    next if /^$/;

    $key = undef;
    $value = undef;
    /^(.*?)\s*=\s*(.*)$/;
    ($key,$value) = ($1,$2);

    $key = lc($key);
    $key =~ s/[^a-z0-9]//g; # Leave numbers and letters only

    # Translate the value to the internal (shorter) version of it
    $key = EtoI($key);

    $Config{$key} = $value;
    if ($MSMRTG::Debug::debug) { MSMRTG::Debug::Debug($key, $value) }
  }

	# If we found a regular expression for MTA name then we need to clean it up
	if ($Config{'mtaalternativename'}) {
		# Get rid of any anchors
		$Config{'mtaalternativename'} =~ s/^\^(.)/$1/g;
		$Config{'mtaalternativename'} =~ s/([^\\])[\$^]/$1/g;
		# Make any brackets non capturing
		$Config{'mtaalternativename'} =~ s/([^\\])\((?:\?:)?/$1(?:/g;
		# If we have still got a string left we wrap it up
		if (length($Config{'mtaalternativename'})) {
			$Config{'mtaalternativename'}="|(?:" . $Config{'mtaalternativename'} . ")";
		}
	} else { $Config{'mtaalternativename'} = "" }
  $fileh->close();
  if ($MSMRTG::Debug::debug) { MSMRTG::Debug::Debug("Leaving sub ReadConfFile") }
}

sub GetTimeDate{
	# This populates all the time related variables so we keep a consistent view 
	# about what the current time and date is.
  if ($MSMRTG::Debug::debug) { MSMRTG::Debug::Debug("Entering sub GetTimeDate") }

	$timedate{'utime'}=time();
  @timedate{qw(sec min hour mday mon year wday yday isdstr)} = localtime($timedate{'utime'});

	# Get text month
  $timedate{'month'} = (qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec))[$timedate{'mon'}]; 
	$timedate{'mon'}++;  # Make month no. 1-12 not 0-11
	$timedate{'year'}+=1900; # Proper 4 digit year

  if ($MSMRTG::Debug::debug){ 
		while (($key, $value) = each %timedate) {
						MSMRTG::Debug::Debug($key, $value);
		}

    MSMRTG::Debug::Debug("Leaving sub GetTimeDate"); 
  }
}
1;
